@@ -3,8 +3,9 @@ Main interface for lambda service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.lambda_ import (
+    from mypy_boto3_lambda import (
         Client,
         FunctionActiveWaiter,
         FunctionExistsWaiter,
@@ -18,7 +19,7 @@ Usage::
         ListLayersPaginator,
         ListProvisionedConcurrencyConfigsPaginator,
         ListVersionsByFunctionPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -37,15 +38,16 @@ Usage::
     list_layers_paginator: ListLayersPaginator = client.get_paginator("list_layers")
     list_provisioned_concurrency_configs_paginator: ListProvisionedConcurrencyConfigsPaginator = client.get_paginator("list_provisioned_concurrency_configs")
     list_versions_by_function_paginator: ListVersionsByFunctionPaginator = client.get_paginator("list_versions_by_function")
+    ```
 """
-from mypy_boto3_lambda.client import LambdaClient, LambdaClient as Client
+from mypy_boto3_lambda.client import LambdaClient
 from mypy_boto3_lambda.paginator import (
     ListAliasesPaginator,
     ListEventSourceMappingsPaginator,
     ListFunctionEventInvokeConfigsPaginator,
     ListFunctionsPaginator,
-    ListLayerVersionsPaginator,
     ListLayersPaginator,
+    ListLayerVersionsPaginator,
     ListProvisionedConcurrencyConfigsPaginator,
     ListVersionsByFunctionPaginator,
 )
@@ -55,6 +57,8 @@ from mypy_boto3_lambda.waiter import (
     FunctionUpdatedWaiter,
 )
 
+Client = LambdaClient
+
 
 __all__ = (
     "Client",
