@@ -3,18 +3,21 @@ Main interface for lambda service type definitions.
 
 Usage::
 
-    from mypy_boto3.lambda_.type_defs import AddLayerVersionPermissionResponseTypeDef
+    ```python
+    from mypy_boto3_lambda.type_defs import AccountLimitTypeDef
 
-    data: AddLayerVersionPermissionResponseTypeDef = {...}
+    data: AccountLimitTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from datetime import datetime
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,33 +25,37 @@ else:
 
 
 __all__ = (
-    "AddLayerVersionPermissionResponseTypeDef",
-    "AddPermissionResponseTypeDef",
-    "AliasRoutingConfigurationTypeDef",
-    "AliasConfigurationTypeDef",
-    "ConcurrencyTypeDef",
-    "DeadLetterConfigTypeDef",
-    "OnFailureTypeDef",
-    "OnSuccessTypeDef",
-    "DestinationConfigTypeDef",
-    "EnvironmentTypeDef",
-    "EventSourceMappingConfigurationTypeDef",
-    "FunctionCodeTypeDef",
-    "EnvironmentErrorTypeDef",
-    "EnvironmentResponseTypeDef",
-    "LayerTypeDef",
-    "TracingConfigResponseTypeDef",
-    "VpcConfigResponseTypeDef",
-    "FunctionConfigurationTypeDef",
-    "FunctionEventInvokeConfigTypeDef",
     "AccountLimitTypeDef",
     "AccountUsageTypeDef",
+    "AliasConfigurationTypeDef",
+    "AliasRoutingConfigurationTypeDef",
+    "ConcurrencyTypeDef",
+    "DeadLetterConfigTypeDef",
+    "DestinationConfigTypeDef",
+    "EnvironmentErrorTypeDef",
+    "EnvironmentResponseTypeDef",
+    "EventSourceMappingConfigurationTypeDef",
+    "FileSystemConfigTypeDef",
+    "FunctionCodeLocationTypeDef",
+    "FunctionConfigurationTypeDef",
+    "FunctionEventInvokeConfigTypeDef",
+    "LayerTypeDef",
+    "LayerVersionContentOutputTypeDef",
+    "LayerVersionsListItemTypeDef",
+    "LayersListItemTypeDef",
+    "OnFailureTypeDef",
+    "OnSuccessTypeDef",
+    "ProvisionedConcurrencyConfigListItemTypeDef",
+    "TracingConfigResponseTypeDef",
+    "VpcConfigResponseTypeDef",
+    "AddLayerVersionPermissionResponseTypeDef",
+    "AddPermissionResponseTypeDef",
+    "EnvironmentTypeDef",
+    "FunctionCodeTypeDef",
     "GetAccountSettingsResponseTypeDef",
     "GetFunctionConcurrencyResponseTypeDef",
-    "FunctionCodeLocationTypeDef",
     "GetFunctionResponseTypeDef",
     "GetLayerVersionPolicyResponseTypeDef",
-    "LayerVersionContentOutputTypeDef",
     "GetLayerVersionResponseTypeDef",
     "GetPolicyResponseTypeDef",
     "GetProvisionedConcurrencyConfigResponseTypeDef",
@@ -59,11 +66,8 @@ __all__ = (
     "ListEventSourceMappingsResponseTypeDef",
     "ListFunctionEventInvokeConfigsResponseTypeDef",
     "ListFunctionsResponseTypeDef",
-    "LayerVersionsListItemTypeDef",
     "ListLayerVersionsResponseTypeDef",
-    "LayersListItemTypeDef",
     "ListLayersResponseTypeDef",
-    "ProvisionedConcurrencyConfigListItemTypeDef",
     "ListProvisionedConcurrencyConfigsResponseTypeDef",
     "ListTagsResponseTypeDef",
     "ListVersionsByFunctionResponseTypeDef",
@@ -75,16 +79,20 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-AddLayerVersionPermissionResponseTypeDef = TypedDict(
-    "AddLayerVersionPermissionResponseTypeDef", {"Statement": str, "RevisionId": str}, total=False
+AccountLimitTypeDef = TypedDict(
+    "AccountLimitTypeDef",
+    {
+        "TotalCodeSize": int,
+        "CodeSizeUnzipped": int,
+        "CodeSizeZipped": int,
+        "ConcurrentExecutions": int,
+        "UnreservedConcurrentExecutions": int,
+    },
+    total=False,
 )
 
-AddPermissionResponseTypeDef = TypedDict(
-    "AddPermissionResponseTypeDef", {"Statement": str}, total=False
-)
-
-AliasRoutingConfigurationTypeDef = TypedDict(
-    "AliasRoutingConfigurationTypeDef", {"AdditionalVersionWeights": Dict[str, float]}, total=False
+AccountUsageTypeDef = TypedDict(
+    "AccountUsageTypeDef", {"TotalCodeSize": int, "FunctionCount": int}, total=False
 )
 
 AliasConfigurationTypeDef = TypedDict(
@@ -94,29 +102,37 @@ AliasConfigurationTypeDef = TypedDict(
         "Name": str,
         "FunctionVersion": str,
         "Description": str,
-        "RoutingConfig": AliasRoutingConfigurationTypeDef,
+        "RoutingConfig": "AliasRoutingConfigurationTypeDef",
         "RevisionId": str,
     },
     total=False,
 )
 
+AliasRoutingConfigurationTypeDef = TypedDict(
+    "AliasRoutingConfigurationTypeDef", {"AdditionalVersionWeights": Dict[str, float]}, total=False
+)
+
 ConcurrencyTypeDef = TypedDict(
     "ConcurrencyTypeDef", {"ReservedConcurrentExecutions": int}, total=False
 )
 
 DeadLetterConfigTypeDef = TypedDict("DeadLetterConfigTypeDef", {"TargetArn": str}, total=False)
 
-OnFailureTypeDef = TypedDict("OnFailureTypeDef", {"Destination": str}, total=False)
-
-OnSuccessTypeDef = TypedDict("OnSuccessTypeDef", {"Destination": str}, total=False)
-
 DestinationConfigTypeDef = TypedDict(
     "DestinationConfigTypeDef",
-    {"OnSuccess": OnSuccessTypeDef, "OnFailure": OnFailureTypeDef},
+    {"OnSuccess": "OnSuccessTypeDef", "OnFailure": "OnFailureTypeDef"},
     total=False,
 )
 
-EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str]}, total=False)
+EnvironmentErrorTypeDef = TypedDict(
+    "EnvironmentErrorTypeDef", {"ErrorCode": str, "Message": str}, total=False
+)
+
+EnvironmentResponseTypeDef = TypedDict(
+    "EnvironmentResponseTypeDef",
+    {"Variables": Dict[str, str], "Error": "EnvironmentErrorTypeDef"},
+    total=False,
+)
 
 EventSourceMappingConfigurationTypeDef = TypedDict(
     "EventSourceMappingConfigurationTypeDef",
@@ -131,7 +147,7 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
         "LastProcessingResult": str,
         "State": str,
         "StateTransitionReason": str,
-        "DestinationConfig": DestinationConfigTypeDef,
+        "DestinationConfig": "DestinationConfigTypeDef",
         "MaximumRecordAgeInSeconds": int,
         "BisectBatchOnFunctionError": bool,
         "MaximumRetryAttempts": int,
@@ -139,32 +155,10 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-FunctionCodeTypeDef = TypedDict(
-    "FunctionCodeTypeDef",
-    {"ZipFile": Union[bytes, IO], "S3Bucket": str, "S3Key": str, "S3ObjectVersion": str},
-    total=False,
-)
+FileSystemConfigTypeDef = TypedDict("FileSystemConfigTypeDef", {"Arn": str, "LocalMountPath": str})
 
-EnvironmentErrorTypeDef = TypedDict(
-    "EnvironmentErrorTypeDef", {"ErrorCode": str, "Message": str}, total=False
-)
-
-EnvironmentResponseTypeDef = TypedDict(
-    "EnvironmentResponseTypeDef",
-    {"Variables": Dict[str, str], "Error": EnvironmentErrorTypeDef},
-    total=False,
-)
-
-LayerTypeDef = TypedDict("LayerTypeDef", {"Arn": str, "CodeSize": int}, total=False)
-
-TracingConfigResponseTypeDef = TypedDict(
-    "TracingConfigResponseTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
-)
-
-VpcConfigResponseTypeDef = TypedDict(
-    "VpcConfigResponseTypeDef",
-    {"SubnetIds": List[str], "SecurityGroupIds": List[str], "VpcId": str},
-    total=False,
+FunctionCodeLocationTypeDef = TypedDict(
+    "FunctionCodeLocationTypeDef", {"RepositoryType": str, "Location": str}, total=False
 )
 
 FunctionConfigurationTypeDef = TypedDict(
@@ -204,14 +198,14 @@ FunctionConfigurationTypeDef = TypedDict(
         "LastModified": str,
         "CodeSha256": str,
         "Version": str,
-        "VpcConfig": VpcConfigResponseTypeDef,
-        "DeadLetterConfig": DeadLetterConfigTypeDef,
-        "Environment": EnvironmentResponseTypeDef,
+        "VpcConfig": "VpcConfigResponseTypeDef",
+        "DeadLetterConfig": "DeadLetterConfigTypeDef",
+        "Environment": "EnvironmentResponseTypeDef",
         "KMSKeyArn": str,
-        "TracingConfig": TracingConfigResponseTypeDef,
+        "TracingConfig": "TracingConfigResponseTypeDef",
         "MasterArn": str,
         "RevisionId": str,
-        "Layers": List[LayerTypeDef],
+        "Layers": List["LayerTypeDef"],
         "State": Literal["Pending", "Active", "Inactive", "Failed"],
         "StateReason": str,
         "StateReasonCode": Literal[
@@ -237,6 +231,7 @@ FunctionConfigurationTypeDef = TypedDict(
             "InvalidSubnet",
             "InvalidSecurityGroup",
         ],
+        "FileSystemConfigs": List["FileSystemConfigTypeDef"],
     },
     total=False,
 )
@@ -248,30 +243,109 @@ FunctionEventInvokeConfigTypeDef = TypedDict(
         "FunctionArn": str,
         "MaximumRetryAttempts": int,
         "MaximumEventAgeInSeconds": int,
-        "DestinationConfig": DestinationConfigTypeDef,
+        "DestinationConfig": "DestinationConfigTypeDef",
     },
     total=False,
 )
 
-AccountLimitTypeDef = TypedDict(
-    "AccountLimitTypeDef",
+LayerTypeDef = TypedDict("LayerTypeDef", {"Arn": str, "CodeSize": int}, total=False)
+
+LayerVersionContentOutputTypeDef = TypedDict(
+    "LayerVersionContentOutputTypeDef",
+    {"Location": str, "CodeSha256": str, "CodeSize": int},
+    total=False,
+)
+
+LayerVersionsListItemTypeDef = TypedDict(
+    "LayerVersionsListItemTypeDef",
     {
-        "TotalCodeSize": int,
-        "CodeSizeUnzipped": int,
-        "CodeSizeZipped": int,
-        "ConcurrentExecutions": int,
-        "UnreservedConcurrentExecutions": int,
+        "LayerVersionArn": str,
+        "Version": int,
+        "Description": str,
+        "CreatedDate": str,
+        "CompatibleRuntimes": List[
+            Literal[
+                "nodejs",
+                "nodejs4.3",
+                "nodejs6.10",
+                "nodejs8.10",
+                "nodejs10.x",
+                "nodejs12.x",
+                "java8",
+                "java11",
+                "python2.7",
+                "python3.6",
+                "python3.7",
+                "python3.8",
+                "dotnetcore1.0",
+                "dotnetcore2.0",
+                "dotnetcore2.1",
+                "dotnetcore3.1",
+                "nodejs4.3-edge",
+                "go1.x",
+                "ruby2.5",
+                "ruby2.7",
+                "provided",
+            ]
+        ],
+        "LicenseInfo": str,
     },
     total=False,
 )
 
-AccountUsageTypeDef = TypedDict(
-    "AccountUsageTypeDef", {"TotalCodeSize": int, "FunctionCount": int}, total=False
+LayersListItemTypeDef = TypedDict(
+    "LayersListItemTypeDef",
+    {"LayerName": str, "LayerArn": str, "LatestMatchingVersion": "LayerVersionsListItemTypeDef"},
+    total=False,
+)
+
+OnFailureTypeDef = TypedDict("OnFailureTypeDef", {"Destination": str}, total=False)
+
+OnSuccessTypeDef = TypedDict("OnSuccessTypeDef", {"Destination": str}, total=False)
+
+ProvisionedConcurrencyConfigListItemTypeDef = TypedDict(
+    "ProvisionedConcurrencyConfigListItemTypeDef",
+    {
+        "FunctionArn": str,
+        "RequestedProvisionedConcurrentExecutions": int,
+        "AvailableProvisionedConcurrentExecutions": int,
+        "AllocatedProvisionedConcurrentExecutions": int,
+        "Status": Literal["IN_PROGRESS", "READY", "FAILED"],
+        "StatusReason": str,
+        "LastModified": str,
+    },
+    total=False,
+)
+
+TracingConfigResponseTypeDef = TypedDict(
+    "TracingConfigResponseTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
+)
+
+VpcConfigResponseTypeDef = TypedDict(
+    "VpcConfigResponseTypeDef",
+    {"SubnetIds": List[str], "SecurityGroupIds": List[str], "VpcId": str},
+    total=False,
+)
+
+AddLayerVersionPermissionResponseTypeDef = TypedDict(
+    "AddLayerVersionPermissionResponseTypeDef", {"Statement": str, "RevisionId": str}, total=False
+)
+
+AddPermissionResponseTypeDef = TypedDict(
+    "AddPermissionResponseTypeDef", {"Statement": str}, total=False
+)
+
+EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str]}, total=False)
+
+FunctionCodeTypeDef = TypedDict(
+    "FunctionCodeTypeDef",
+    {"ZipFile": bytes, "S3Bucket": str, "S3Key": str, "S3ObjectVersion": str},
+    total=False,
 )
 
 GetAccountSettingsResponseTypeDef = TypedDict(
     "GetAccountSettingsResponseTypeDef",
-    {"AccountLimit": AccountLimitTypeDef, "AccountUsage": AccountUsageTypeDef},
+    {"AccountLimit": "AccountLimitTypeDef", "AccountUsage": "AccountUsageTypeDef"},
     total=False,
 )
 
@@ -279,17 +353,13 @@ GetFunctionConcurrencyResponseTypeDef = TypedDict(
     "GetFunctionConcurrencyResponseTypeDef", {"ReservedConcurrentExecutions": int}, total=False
 )
 
-FunctionCodeLocationTypeDef = TypedDict(
-    "FunctionCodeLocationTypeDef", {"RepositoryType": str, "Location": str}, total=False
-)
-
 GetFunctionResponseTypeDef = TypedDict(
     "GetFunctionResponseTypeDef",
     {
-        "Configuration": FunctionConfigurationTypeDef,
-        "Code": FunctionCodeLocationTypeDef,
+        "Configuration": "FunctionConfigurationTypeDef",
+        "Code": "FunctionCodeLocationTypeDef",
         "Tags": Dict[str, str],
-        "Concurrency": ConcurrencyTypeDef,
+        "Concurrency": "ConcurrencyTypeDef",
     },
     total=False,
 )
@@ -298,16 +368,10 @@ GetLayerVersionPolicyResponseTypeDef = TypedDict(
     "GetLayerVersionPolicyResponseTypeDef", {"Policy": str, "RevisionId": str}, total=False
 )
 
-LayerVersionContentOutputTypeDef = TypedDict(
-    "LayerVersionContentOutputTypeDef",
-    {"Location": str, "CodeSha256": str, "CodeSize": int},
-    total=False,
-)
-
 GetLayerVersionResponseTypeDef = TypedDict(
     "GetLayerVersionResponseTypeDef",
     {
-        "Content": LayerVersionContentOutputTypeDef,
+        "Content": "LayerVersionContentOutputTypeDef",
         "LayerArn": str,
         "LayerVersionArn": str,
         "Description": str,
@@ -366,7 +430,7 @@ InvocationResponseTypeDef = TypedDict(
         "StatusCode": int,
         "FunctionError": str,
         "LogResult": str,
-        "Payload": Union[bytes, IO],
+        "Payload": bytes,
         "ExecutedVersion": str,
     },
     total=False,
@@ -376,107 +440,50 @@ InvokeAsyncResponseTypeDef = TypedDict("InvokeAsyncResponseTypeDef", {"Status":
 
 LayerVersionContentInputTypeDef = TypedDict(
     "LayerVersionContentInputTypeDef",
-    {"S3Bucket": str, "S3Key": str, "S3ObjectVersion": str, "ZipFile": Union[bytes, IO]},
+    {"S3Bucket": str, "S3Key": str, "S3ObjectVersion": str, "ZipFile": bytes},
     total=False,
 )
 
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef",
-    {"NextMarker": str, "Aliases": List[AliasConfigurationTypeDef]},
+    {"NextMarker": str, "Aliases": List["AliasConfigurationTypeDef"]},
     total=False,
 )
 
 ListEventSourceMappingsResponseTypeDef = TypedDict(
     "ListEventSourceMappingsResponseTypeDef",
-    {"NextMarker": str, "EventSourceMappings": List[EventSourceMappingConfigurationTypeDef]},
+    {"NextMarker": str, "EventSourceMappings": List["EventSourceMappingConfigurationTypeDef"]},
     total=False,
 )
 
 ListFunctionEventInvokeConfigsResponseTypeDef = TypedDict(
     "ListFunctionEventInvokeConfigsResponseTypeDef",
-    {"FunctionEventInvokeConfigs": List[FunctionEventInvokeConfigTypeDef], "NextMarker": str},
+    {"FunctionEventInvokeConfigs": List["FunctionEventInvokeConfigTypeDef"], "NextMarker": str},
     total=False,
 )
 
 ListFunctionsResponseTypeDef = TypedDict(
     "ListFunctionsResponseTypeDef",
-    {"NextMarker": str, "Functions": List[FunctionConfigurationTypeDef]},
-    total=False,
-)
-
-LayerVersionsListItemTypeDef = TypedDict(
-    "LayerVersionsListItemTypeDef",
-    {
-        "LayerVersionArn": str,
-        "Version": int,
-        "Description": str,
-        "CreatedDate": str,
-        "CompatibleRuntimes": List[
-            Literal[
-                "nodejs",
-                "nodejs4.3",
-                "nodejs6.10",
-                "nodejs8.10",
-                "nodejs10.x",
-                "nodejs12.x",
-                "java8",
-                "java11",
-                "python2.7",
-                "python3.6",
-                "python3.7",
-                "python3.8",
-                "dotnetcore1.0",
-                "dotnetcore2.0",
-                "dotnetcore2.1",
-                "dotnetcore3.1",
-                "nodejs4.3-edge",
-                "go1.x",
-                "ruby2.5",
-                "ruby2.7",
-                "provided",
-            ]
-        ],
-        "LicenseInfo": str,
-    },
+    {"NextMarker": str, "Functions": List["FunctionConfigurationTypeDef"]},
     total=False,
 )
 
 ListLayerVersionsResponseTypeDef = TypedDict(
     "ListLayerVersionsResponseTypeDef",
-    {"NextMarker": str, "LayerVersions": List[LayerVersionsListItemTypeDef]},
-    total=False,
-)
-
-LayersListItemTypeDef = TypedDict(
-    "LayersListItemTypeDef",
-    {"LayerName": str, "LayerArn": str, "LatestMatchingVersion": LayerVersionsListItemTypeDef},
+    {"NextMarker": str, "LayerVersions": List["LayerVersionsListItemTypeDef"]},
     total=False,
 )
 
 ListLayersResponseTypeDef = TypedDict(
     "ListLayersResponseTypeDef",
-    {"NextMarker": str, "Layers": List[LayersListItemTypeDef]},
-    total=False,
-)
-
-ProvisionedConcurrencyConfigListItemTypeDef = TypedDict(
-    "ProvisionedConcurrencyConfigListItemTypeDef",
-    {
-        "FunctionArn": str,
-        "RequestedProvisionedConcurrentExecutions": int,
-        "AvailableProvisionedConcurrentExecutions": int,
-        "AllocatedProvisionedConcurrentExecutions": int,
-        "Status": Literal["IN_PROGRESS", "READY", "FAILED"],
-        "StatusReason": str,
-        "LastModified": str,
-    },
+    {"NextMarker": str, "Layers": List["LayersListItemTypeDef"]},
     total=False,
 )
 
 ListProvisionedConcurrencyConfigsResponseTypeDef = TypedDict(
     "ListProvisionedConcurrencyConfigsResponseTypeDef",
     {
-        "ProvisionedConcurrencyConfigs": List[ProvisionedConcurrencyConfigListItemTypeDef],
+        "ProvisionedConcurrencyConfigs": List["ProvisionedConcurrencyConfigListItemTypeDef"],
         "NextMarker": str,
     },
     total=False,
@@ -488,7 +495,7 @@ ListTagsResponseTypeDef = TypedDict(
 
 ListVersionsByFunctionResponseTypeDef = TypedDict(
     "ListVersionsByFunctionResponseTypeDef",
-    {"NextMarker": str, "Versions": List[FunctionConfigurationTypeDef]},
+    {"NextMarker": str, "Versions": List["FunctionConfigurationTypeDef"]},
     total=False,
 )
 
@@ -499,7 +506,7 @@ PaginatorConfigTypeDef = TypedDict(
 PublishLayerVersionResponseTypeDef = TypedDict(
     "PublishLayerVersionResponseTypeDef",
     {
-        "Content": LayerVersionContentOutputTypeDef,
+        "Content": "LayerVersionContentOutputTypeDef",
         "LayerArn": str,
         "LayerVersionArn": str,
         "Description": str,
